@@ -17,12 +17,17 @@ class DocumentSerializer(serializers.ModelSerializer):
             'filename',
             'project',
             'uploaded_at',
-            'uploaded_by',
         )
-        read_only_fields = 'creator', 'filename', 'uploaded_at', 'uploaded_by'
+        read_only_fields = 'creator', 'filename', 'uploaded_at', 'project'
 
     def create(self, validated_data):
-        return services.create_document(**validated_data)
+        project = self.context['project']
+        return services.create_document(project, **validated_data)
+
+    def to_representation(self, document):
+        data = super().to_representation(document)
+        data['uploaded_by'] = document.uploaded_by.get_full_name()
+        return data
 
 
 class DocumentTypeSerializer(serializers.ModelSerializer):
