@@ -19,6 +19,11 @@ class DocumentViewSet(mixins.CreateModelMixin, mixins.DestroyModelMixin, mixins.
     def get_queryset(self):
         return services.get_documents(self.project)
 
+    def get_serializer_context(self):
+        context = super().get_serializer_context()
+        context['project'] = self.project
+        return context
+
 
 class DocumentTypeViewSet(mixins.CreateModelMixin, mixins.DestroyModelMixin, mixins.ListModelMixin,
                           mixins.UpdateModelMixin, viewsets.GenericViewSet):
